import * as React from "react";
import type { Classes, MergeElementProps } from "../typings";
interface OwnProps {
    /**
     * The content of the breadcrumb.
     */
    children?: React.ReactNode;
    /**
     * Map of sub-components and their correlated classNames.
     */
    classes?: Classes<"root" | "label" | "list">;
    /**
     * The label of the breadcrumb.
     */
    label: string | {
        /**
         * The label to use as `aria-label` property.
         */
        screenReaderLabel: string;
    } | {
        /**
         * Identifies the element (or elements) that labels the breadcrumb.
         *
         * @see {@link https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Attributes/aria-labelledby MDN Web Docs} for more information.
         */
        labelledBy: string;
    };
}
export type Props = Omit<MergeElementProps<"nav", OwnProps>, "className" | "defaultChecked" | "defaultValue">;
declare const Breadcrumb: (props: Props, ref: React.Ref<HTMLElement>) => JSX.Element;
export default Breadcrumb;
