import * as React from "react";
import type { Classes, MergeElementProps } from "../../typings";
interface OwnProps {
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Map of sub-components and their correlated classNames.
     */
    classes?: Classes<"root" | "label">;
    /**
     * The label of the tablist.
     */
    label: string | {
        /**
         * The label to use as `aria-label` property.
         */
        screenReaderLabel: string;
    } | {
        /**
         * Identifies the element (or elements) that labels the tablist.
         *
         * @see {@link https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Attributes/aria-labelledby MDN Web Docs} for more information.
         */
        labelledBy: string;
    };
}
export type Props = Omit<MergeElementProps<"div", OwnProps>, "className" | "defaultChecked" | "defaultValue">;
declare const TabList: (props: Props, ref: React.Ref<HTMLDivElement>) => JSX.Element;
export default TabList;
